"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const node_assert_1 = __importDefault(require("node:assert"));
const node_test_1 = require("node:test");
const m_dcql_query_js_1 = require("./m-dcql-query.js");
/**
 * The following is a non-normative example of a DCQL query that requests
 * a Verifiable Credential in the format mso_mdoc with the claims vehicle_holder and first_name:
 */
const mdocMvrcQuery = {
    credentials: [
        {
            id: 'my_credential',
            format: 'mso_mdoc',
            meta: {
                doctype_value: 'org.iso.7367.1.mVRC',
            },
            claims: [
                {
                    namespace: 'org.iso.7367.1',
                    claim_name: 'vehicle_holder',
                },
                {
                    namespace: 'org.iso.18013.5.1',
                    claim_name: 'first_name',
                },
            ],
        },
    ],
};
const mdocMvrc = {
    docType: 'org.iso.7367.1.mVRC',
    namespaces: {
        'org.iso.7367.1': {
            vehicle_holder: 'Martin Auer',
            non_disclosed: 'secret',
        },
        'org.iso.18013.5.1': { first_name: 'Martin Auer' },
    },
};
const exampleMdoc = {
    docType: 'example_doctype',
    namespaces: {
        example_namespaces: {
            example_claim: 'example_value',
        },
    },
};
const sdJwtVcExample = {
    credentials: [
        {
            id: 'my_credential',
            format: 'vc+sd-jwt',
            meta: {
                vct_values: ['https://credentials.example.com/identity_credential'],
            },
            claims: [
                { path: ['last_name'] },
                { path: ['first_name'] },
                { path: ['address', 'street_address'] },
            ],
        },
    ],
};
const sdJwtVc = {
    vct: 'https://credentials.example.com/identity_credential',
    claims: {
        first_name: 'Arthur',
        last_name: 'Dent',
        address: {
            street_address: '42 Market Street',
            locality: 'Milliways',
            postal_code: '12345',
        },
        degrees: [
            {
                type: 'Bachelor of Science',
                university: 'University of Betelgeuse',
            },
            {
                type: 'Master of Science',
                university: 'University of Betelgeuse',
            },
        ],
        nationalities: ['British', 'Betelgeusian'],
    },
};
void (0, node_test_1.describe)('credential-parser', () => {
    void (0, node_test_1.it)('mdocMvrc example succeeds', _t => {
        const query = m_dcql_query_js_1.DcqlQuery.parse(mdocMvrcQuery);
        m_dcql_query_js_1.DcqlQuery.validate(query);
        const res = m_dcql_query_js_1.DcqlQuery.query(query, [mdocMvrc]);
        (0, node_assert_1.default)(res.canBeSatisfied);
        node_assert_1.default.deepStrictEqual(res.credential_matches, {
            my_credential: {
                issues: undefined,
                success: true,
                typed: true,
                credential_index: 0,
                claim_set_index: undefined,
                output: {
                    docType: 'org.iso.7367.1.mVRC',
                    namespaces: {
                        'org.iso.7367.1': { vehicle_holder: 'Martin Auer' },
                        'org.iso.18013.5.1': { first_name: 'Martin Auer' },
                    },
                },
                all: res.credential_matches.my_credential?.all,
            },
        });
    });
    void (0, node_test_1.it)('mdocMvrc example with multiple credentials succeeds', _t => {
        const query = m_dcql_query_js_1.DcqlQuery.parse(mdocMvrcQuery);
        m_dcql_query_js_1.DcqlQuery.validate(query);
        const res = m_dcql_query_js_1.DcqlQuery.query(query, [exampleMdoc, mdocMvrc]);
        (0, node_assert_1.default)(res.canBeSatisfied);
        node_assert_1.default.deepStrictEqual(res.credential_matches, {
            my_credential: {
                issues: undefined,
                success: true,
                typed: true,
                credential_index: 1,
                claim_set_index: undefined,
                output: {
                    docType: 'org.iso.7367.1.mVRC',
                    namespaces: {
                        'org.iso.7367.1': { vehicle_holder: 'Martin Auer' },
                        'org.iso.18013.5.1': { first_name: 'Martin Auer' },
                    },
                },
                all: res.credential_matches.my_credential?.all,
            },
        });
    });
    void (0, node_test_1.it)('sdJwtVc example with multiple credentials succeeds', _t => {
        const query = m_dcql_query_js_1.DcqlQuery.parse(sdJwtVcExample);
        m_dcql_query_js_1.DcqlQuery.validate(query);
        const res = m_dcql_query_js_1.DcqlQuery.query(query, [exampleMdoc, sdJwtVc]);
        (0, node_assert_1.default)(res.canBeSatisfied);
        node_assert_1.default.deepStrictEqual(res.credential_matches, {
            my_credential: {
                issues: undefined,
                success: true,
                typed: true,
                credential_index: 1,
                claim_set_index: undefined,
                output: {
                    vct: 'https://credentials.example.com/identity_credential',
                    claims: {
                        first_name: 'Arthur',
                        last_name: 'Dent',
                        address: {
                            street_address: '42 Market Street',
                        },
                    },
                },
                all: res.credential_matches.my_credential?.all,
            },
        });
    });
});
//# sourceMappingURL=dcql-query.test.js.map